==> pdf-model-arlington-1.25.17-sources.jar: org/verapdf/model/alayer/AFieldTx.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AFieldTx extends AObject {
	







	/**
	*/
	public Boolean getcontainsAA();

	/**
	*/
	public Boolean getAAHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsDA();

	/**
	*/
	public Boolean getDAHasTypeStringByte();

	/**
	*/
	public Boolean getcontainsDS();

	/**
	*/
	public Boolean getDSHasTypeStringText();

	/**
	*/
	public Boolean getcontainsDV();

	/**
	*/
	public Boolean getisDVIndirect();

	/**
	*/
	public Boolean getDVHasTypeStream();

	/**
	*/
	public Boolean getDVHasTypeStringText();

	/**
	*/
	public Boolean getcontainsFT();

	/**
	*/
	public Boolean getFTHasTypeName();

	/**
	*/
	public String getFTNameValue();

	/**
	*/
	public Boolean getcontainsFf();

	/**
	*/
	public Boolean getFfHasTypeBitmask();

	/**
	*/
	public Long getFfBitmaskValue();

	/**
	*/
	public Boolean getcontainsKids();

	/**
	*/
	public Boolean getKidsHasTypeArray();

	/**
	*/
	public Boolean getcontainsMaxLen();

	/**
	*/
	public Boolean getMaxLenHasTypeInteger();

	/**
	*/
	public Long getMaxLenIntegerValue();

	/**
	*/
	public Boolean getcontainsParent();

	/**
	*/
	public Boolean getParentHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsQ();

	/**
	*/
	public Boolean getQHasTypeInteger();

	/**
	*/
	public Long getQIntegerValue();

	/**
	*/
	public Boolean getcontainsRV();

	/**
	*/
	public Boolean getisRVIndirect();

	/**
	*/
	public Boolean getRVHasTypeStream();

	/**
	*/
	public Boolean getRVHasTypeStringText();

	/**
	*/
	public Boolean getcontainsT();

	/**
	*/
	public Boolean getTHasTypeStringText();

	/**
	*/
	public Boolean getcontainsTM();

	/**
	*/
	public Boolean getTMHasTypeStringText();

	/**
	*/
	public Boolean getcontainsTU();

	/**
	*/
	public Boolean getTUHasTypeStringText();

	/**
	*/
	public Boolean getcontainsV();

	/**
	*/
	public Boolean getisVIndirect();

	/**
	*/
	public Boolean getVHasTypeStream();

	/**
	*/
	public Boolean getVHasTypeStringText();
}

==> pdf-model-arlington-1.25.44-sources.jar: org/verapdf/model/alayer/AFieldTx.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AFieldTx extends AObject {
	







	/**
	*/
	public Boolean getcontainsAA();

	/**
	*/
	public String getAAType();

	/**
	*/
	public Boolean getAAHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsDA();

	/**
	*/
	public String getDAType();

	/**
	*/
	public Boolean getDAHasTypeStringByte();

	/**
	*/
	public Boolean getcontainsDS();

	/**
	*/
	public String getDSType();

	/**
	*/
	public Boolean getDSHasTypeStringText();

	/**
	*/
	public Boolean getcontainsDV();

	/**
	*/
	public Boolean getisDVIndirect();

	/**
	*/
	public String getDVType();

	/**
	*/
	public Boolean getDVHasTypeStream();

	/**
	*/
	public Boolean getDVHasTypeStringText();

	/**
	*/
	public Boolean getcontainsFT();

	/**
	*/
	public String getFTType();

	/**
	*/
	public Boolean getFTHasTypeName();

	/**
	*/
	public String getFTNameValue();

	/**
	*/
	public Boolean getcontainsFf();

	/**
	*/
	public String getFfType();

	/**
	*/
	public Boolean getFfHasTypeBitmask();

	/**
	*/
	public Long getFfBitmaskValue();

	/**
	*/
	public Boolean getcontainsKids();

	/**
	*/
	public String getKidsType();

	/**
	*/
	public Boolean getKidsHasTypeArray();

	/**
	*/
	public Boolean getcontainsMaxLen();

	/**
	*/
	public String getMaxLenType();

	/**
	*/
	public Boolean getMaxLenHasTypeInteger();

	/**
	*/
	public Long getMaxLenIntegerValue();

	/**
	*/
	public Boolean getcontainsParent();

	/**
	*/
	public String getParentType();

	/**
	*/
	public Boolean getParentHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsQ();

	/**
	*/
	public String getQType();

	/**
	*/
	public Boolean getQHasTypeInteger();

	/**
	*/
	public Long getQIntegerValue();

	/**
	*/
	public Boolean getcontainsRV();

	/**
	*/
	public Boolean getisRVIndirect();

	/**
	*/
	public String getRVType();

	/**
	*/
	public Boolean getRVHasTypeStream();

	/**
	*/
	public Boolean getRVHasTypeStringText();

	/**
	*/
	public Boolean getcontainsT();

	/**
	*/
	public String getTType();

	/**
	*/
	public Boolean getTHasTypeStringText();

	/**
	*/
	public Boolean getcontainsTM();

	/**
	*/
	public String getTMType();

	/**
	*/
	public Boolean getTMHasTypeStringText();

	/**
	*/
	public Boolean getcontainsTU();

	/**
	*/
	public String getTUType();

	/**
	*/
	public Boolean getTUHasTypeStringText();

	/**
	*/
	public Boolean getcontainsV();

	/**
	*/
	public Boolean getisVIndirect();

	/**
	*/
	public String getVType();

	/**
	*/
	public Boolean getVHasTypeStream();

	/**
	*/
	public Boolean getVHasTypeStringText();
}
